// UrlRewriter - A .NET URL Rewriter module
// Version 1.5
//
// Copyright 2005 Intelligencia
// Copyright 2005 Seth Yates
// 

using System;
using System.Collections;
using Intelligencia.UrlRewriter.Conditions;

namespace Intelligencia.UrlRewriter.Actions
{
	/// <summary>
	/// A Conditional Action
	/// </summary>
	internal class ConditionalAction : IRewriteAction, IRewriteCondition
	{
		/// <summary>
		/// Default constructor.
		/// </summary>
		public ConditionalAction()
		{
		}

		/// <summary>
		/// Conditions that must hold for the rule to fire.
		/// </summary>
		public IList Conditions
		{
			get
			{
				return _conditions;
			}
		}

		/// <summary>
		/// Child rules.
		/// </summary>
		public IList Actions
		{
			get
			{
				return _actions;
			}
		}

		public virtual bool IsMatch(RewriteContext context)
		{
			// Ensure the conditions are met.
			foreach (IRewriteCondition condition in Conditions)
			{
				if (!condition.IsMatch(context))
				{
					return false;
				}
			}

			return true;
		}

		/// <summary>
		/// Executes the rule.
		/// </summary>
		/// <param name="context"></param>
		public virtual void Execute(RewriteContext context)
		{
			// Execute the actions.
			for (int i = 0; i < Actions.Count; i++)
			{
				IRewriteCondition condition = Actions[i] as IRewriteCondition;
				if (condition == null || condition.IsMatch(context))
				{
					IRewriteAction action = Actions[i] as IRewriteAction;
					action.Execute(context);
					if (action.Processing != RewriteProcessing.ContinueProcessing)
					{
						_processing = action.Processing;
						return;
					}
				}
			}
		}

		/// <summary>
		/// Processing directive.
		/// </summary>
		public RewriteProcessing Processing
		{
			get
			{
				return _processing;
			}
		}

		private RewriteProcessing _processing = RewriteProcessing.ContinueProcessing;
		private ArrayList _actions = new ArrayList();
		private ArrayList _conditions = new ArrayList();
	}
}
