// UrlRewriter - A .NET URL Rewriter module
// Version 1.5
//
// Copyright 2005 Intelligencia
// Copyright 2005 Seth Yates
// 

using System;
using System.Web;
using System.Collections;
using Intelligencia.UrlRewriter.Conditions;

namespace Intelligencia.UrlRewriter.Actions
{
	/// <summary>
	/// Rewrites in-place.
	/// </summary>
	internal sealed class RewriteAction : SetLocationAction, IRewriteCondition
	{
		/// <summary>
		/// Default constructor.
		/// </summary>
		/// <param name="location">The location to set.</param>
		/// <param name="processing">The processing directive.</param>
		public RewriteAction(string location, RewriteProcessing processing) : base(location)
		{
			_processing = processing;
		}

		/// <summary>
		/// Executes the action.
		/// </summary>
		/// <param name="context">The rewrite context.</param>
		public override void Execute(RewriteContext context)
		{
			base.Execute(context);
		}

		/// <summary>
		/// The Processing directive.
		/// </summary>
		public override RewriteProcessing Processing
		{
			get
			{
				return _processing;
			}
		}

		/// <summary>
		/// Determines if the rewrite rule matches.
		/// </summary>
		/// <param name="context"></param>
		/// <returns></returns>
		public bool IsMatch(RewriteContext context)
		{
			// Ensure the conditions are met.
			foreach (IRewriteCondition condition in Conditions)
			{
				if (!condition.IsMatch(context))
				{
					return false;
				}
			}

			return true;
		}

		/// <summary>
		/// Conditions that must hold for the rule to fire.
		/// </summary>
		public IList Conditions
		{
			get
			{
				return _conditions;
			}
		}

		private ArrayList _conditions = new ArrayList();
		private RewriteProcessing _processing;
	}
}
