// UrlRewriter - A .NET URL Rewriter module
// Version 1.5
//
// Copyright 2005 Intelligencia
// Copyright 2005 Seth Yates
// 

using System;
using System.Web;

namespace Intelligencia.UrlRewriter.Actions
{
	/// <summary>
	/// Action that sets a cookie.
	/// </summary>
	internal class SetCookieAction : IRewriteAction
	{
		/// <summary>
		/// Default constructor.
		/// </summary>
		/// <param name="cookieName">The cookie name.</param>
		/// <param name="cookieValue">The cookie value.</param>
		public SetCookieAction(string cookieName, string cookieValue)
		{
			_name = cookieName;
			_value = cookieValue;
		}

		/// <summary>
		/// The name of the variable.
		/// </summary>
		public string Name
		{
			get
			{
				return _name;
			}
			set
			{
				_name = value;
			}
		}

		/// <summary>
		/// The value of the variable.
		/// </summary>
		public string Value
		{
			get
			{
				return _value;
			}
			set
			{
				_value = value;
			}
		}

		/// <summary>
		/// Executes the action.
		/// </summary>
		/// <param name="context">The rewrite context.</param>
		public void Execute(RewriteContext context)
		{
			HttpCookie cookie = new HttpCookie(Name, Value);
			context.Cookies.Add(cookie);
		}

		/// <summary>
		/// The Processing directive.
		/// </summary>
		public RewriteProcessing Processing
		{
			get
			{
				return RewriteProcessing.ContinueProcessing;
			}
		}

		private string _name;
		private string _value;
	}
}
