// UrlRewriter - A .NET URL Rewriter module
// Version 1.5
//
// Copyright 2005 Intelligencia
// Copyright 2005 Seth Yates
// 

using System;

namespace Intelligencia.UrlRewriter.Actions
{
	/// <summary>
	/// Action that sets properties in the context.
	/// </summary>
	internal class SetPropertyAction : IRewriteAction
	{
		/// <summary>
		/// Default constructor.
		/// </summary>
		/// <param name="name">The name of the variable.</param>
		/// <param name="value">The name of the value.</param>
		public SetPropertyAction(string name, string value)
		{
			_name = name;
			_value = value;
		}

		/// <summary>
		/// The name of the variable.
		/// </summary>
		public string Name
		{
			get
			{
				return _name;
			}
			set
			{
				_name = value;
			}
		}

		/// <summary>
		/// The value of the variable.
		/// </summary>
		public string Value
		{
			get
			{
				return _value;
			}
			set
			{
				_value = value;
			}
		}

		/// <summary>
		/// Executes the action.
		/// </summary>
		/// <param name="context">The rewrite context.</param>
		public void Execute(RewriteContext context)
		{
			context.Properties.Set(Name, Value);
		}

		/// <summary>
		/// The Processing directive.
		/// </summary>
		public RewriteProcessing Processing
		{
			get
			{
				return RewriteProcessing.ContinueProcessing;
			}
		}

		private string _name;
		private string _value;
	}
}
