// UrlRewriter - A .NET URL Rewriter module
// Version 1.5
//
// Copyright 2005 Intelligencia
// Copyright 2005 Seth Yates
// 

using System;
using System.Net;
using System.Text.RegularExpressions;
using Intelligencia.UrlRewriter.Utilities;

namespace Intelligencia.UrlRewriter.Conditions
{
	/// <summary>
	/// Matches on the current remote IP address.
	/// </summary>
	internal sealed class AddressCondition : IRewriteCondition
	{
		/// <summary>
		/// Default constructor.
		/// </summary>
		/// <param name="pattern"></param>
		public AddressCondition(string pattern)
		{
			_range = IPRange.Parse(pattern);
		}

		/// <summary>
		/// Determines if the condition is matched.
		/// </summary>
		/// <param name="context">The rewriting context.</param>
		/// <returns>True if the condition is met.</returns>
		public bool IsMatch(RewriteContext context)
		{
			string ipAddress = context.Properties[Constants.RemoteAddressHeader];
			if (ipAddress != null)
			{
				return _range.InRange(IPAddress.Parse(ipAddress));
			}
			else
			{
				return false;
			}
		}

		private IPRange _range;
	}
}
