// UrlRewriter - A .NET URL Rewriter module
// Version 1.5
//
// Copyright 2005 Intelligencia
// Copyright 2005 Seth Yates
// 

using System;
using System.IO;
using System.Net;
using System.Web;
using System.Text.RegularExpressions;
using Intelligencia.UrlRewriter.Utilities;

namespace Intelligencia.UrlRewriter.Conditions
{
	/// <summary>
	/// Condition that tests the existence of a file.
	/// </summary>
	internal class ExistsCondition : IRewriteCondition
	{
		/// <summary>
		/// Constructor.
		/// </summary>
		/// <param name="location"></param>
		public ExistsCondition(string location)
		{
			_location = location;
		}

		/// <summary>
		/// Determines if the condition is matched.
		/// </summary>
		/// <param name="context">The rewriting context.</param>
		/// <returns>True if the condition is met.</returns>
		public bool IsMatch(RewriteContext context)
		{
			string filename = HttpContext.Current.Server.MapPath(context.Expand(_location));
			return File.Exists(filename) || Directory.Exists(filename);
		}

		private string _location;
	}
}
