// UrlRewriter - A .NET URL Rewriter module
// Version 1.5
//
// Copyright 2005 Intelligencia
// Copyright 2005 Seth Yates
// 

using System;
using System.Text.RegularExpressions;

namespace Intelligencia.UrlRewriter.Conditions
{
	/// <summary>
	/// Base class for MatchConditions.
	/// </summary>
	internal abstract class MatchCondition : IRewriteCondition
	{
		/// <summary>
		/// Default constructor.
		/// </summary>
		/// <param name="pattern">Pattern to match.</param>
		public MatchCondition(string pattern)
		{
			_pattern = new Regex(pattern);
		}

		/// <summary>
		/// Whether the MatchCondition is to be negated.
		/// </summary>
		public bool Negative
		{
			get
			{
				return _negative;
			}
			set
			{
				_negative = value;
			}
		}

		/// <summary>
		/// The pattern to match.
		/// </summary>
		public Regex Pattern
		{
			get
			{
				return _pattern;
			}
			set
			{
				_pattern = value;
			}
		}

		/// <summary>
		/// Determines if the condition is matched.
		/// </summary>
		/// <param name="context">The rewriting context.</param>
		/// <returns>True if the condition is met.</returns>
		public abstract bool IsMatch(RewriteContext context);

		private bool _negative = false;
		private Regex _pattern;
	}
}
