// UrlRewriter - A .NET URL Rewriter module
// Version 1.5
//
// Copyright 2005 Intelligencia
// Copyright 2005 Seth Yates
// 

using System;
using System.Web;
using System.Text.RegularExpressions;

namespace Intelligencia.UrlRewriter.Conditions
{
	/// <summary>
	/// Matches on the current URL.
	/// </summary>
	internal sealed class UrlMatchCondition : MatchCondition
	{
		/// <summary>
		/// Default constructor.
		/// </summary>
		/// <param name="pattern"></param>
		public UrlMatchCondition(string pattern) : base(pattern.Replace("~/", HttpContext.Current.Request.ApplicationPath + "/"))
		{
		}

		/// <summary>
		/// Determines if the condition is matched.
		/// </summary>
		/// <param name="context">The rewriting context.</param>
		/// <returns>True if the condition is met.</returns>
		public override bool IsMatch(RewriteContext context)
		{
			Match match = Pattern.Match(context.Location);
			if (match.Success)
			{
				context.LastMatch = match;
				return true;
			}
			else
			{
				return false;
			}
		}
	}
}
