// UrlRewriter - A .NET URL Rewriter module
// Version 1.5
//
// Copyright 2005 Intelligencia
// Copyright 2005 Seth Yates
// 

using System;
using System.Xml;
using System.Text.RegularExpressions;
using System.Collections;
using System.Configuration;
using System.Reflection;
using Intelligencia.UrlRewriter.Parsers;
using Intelligencia.UrlRewriter.Transforms;
using Intelligencia.UrlRewriter.Utilities;

namespace Intelligencia.UrlRewriter.Configuration
{
	/// <summary>
	/// Configuration for the URL rewriter.
	/// </summary>
	public class RewriterConfiguration
	{
		/// <summary>
		/// Default constructor.
		/// </summary>
		internal RewriterConfiguration()
		{
			_xPoweredBy = MessageProvider.FormatString(Message.ProductName, Assembly.GetExecutingAssembly().GetName().Version.ToString(3));

			_actionParserFactory = new ActionParserFactory();
			_actionParserFactory.AddParser(new ConditionActionParser());
			_actionParserFactory.AddParser(new AddHeaderActionParser());
			_actionParserFactory.AddParser(new SetCookieActionParser());
			_actionParserFactory.AddParser(new SetPropertyActionParser());
			_actionParserFactory.AddParser(new RewriteActionParser());
			_actionParserFactory.AddParser(new IfRewriteActionParser());
			_actionParserFactory.AddParser(new RedirectActionParser());
			_actionParserFactory.AddParser(new IfRedirectActionParser());
			_actionParserFactory.AddParser(new SetStatusActionParser());
			_actionParserFactory.AddParser(new ForbiddenActionParser());
			_actionParserFactory.AddParser(new GoneActionParser());
			_actionParserFactory.AddParser(new NotAllowedActionParser());
			_actionParserFactory.AddParser(new NotFoundActionParser());
			_actionParserFactory.AddParser(new NotImplementedActionParser());

			_conditionParserPipeline = new ConditionParserPipeline();
			_conditionParserPipeline.AddParser(new AddressConditionParser());
			_conditionParserPipeline.AddParser(new HeaderMatchConditionParser());
			_conditionParserPipeline.AddParser(new MethodConditionParser());
			_conditionParserPipeline.AddParser(new PropertyMatchConditionParser());
			_conditionParserPipeline.AddParser(new ExistsConditionParser());
			_conditionParserPipeline.AddParser(new UrlMatchConditionParser());

			_transformFactory = new TransformFactory();
			_transformFactory.AddTransform(new DecodeTransform());
			_transformFactory.AddTransform(new EncodeTransform());
			_transformFactory.AddTransform(new LowerTransform());
			_transformFactory.AddTransform(new UpperTransform());
			_transformFactory.AddTransform(new Base64Transform());
			_transformFactory.AddTransform(new Base64DecodeTransform());
		}

		/// <summary>
		/// The rules.
		/// </summary>
		public IList Rules
		{
			get
			{
				return _rules;
			}
		}

		/// <summary>
		/// The action parser factory.
		/// </summary>
		public ActionParserFactory ActionParserFactory
		{
			get
			{
				return _actionParserFactory;
			}
		}

		/// <summary>
		/// The transform factory.
		/// </summary>
		public TransformFactory TransformFactory
		{
			get
			{
				return _transformFactory;
			}
		}

		/// <summary>
		/// The condition parser pipeline.
		/// </summary>
		public ConditionParserPipeline ConditionParserPipeline
		{
			get
			{
				return _conditionParserPipeline;
			}
		}

		/// <summary>
		/// Dictionary of error handlers.
		/// </summary>
		public IDictionary ErrorHandlers
		{
			get
			{
				return _errorHandlers;
			}
		}

		internal string XPoweredBy
		{
			get
			{
				return _xPoweredBy;
			}
		}

		private Hashtable _errorHandlers = new Hashtable();
		private ArrayList _rules = new ArrayList();
		private ActionParserFactory _actionParserFactory;
		private ConditionParserPipeline _conditionParserPipeline;
		private TransformFactory _transformFactory;
		private string _xPoweredBy;
	}
}
