// UrlRewriter - A .NET URL Rewriter module
// Version 1.5
//
// Copyright 2005 Intelligencia
// Copyright 2005 Seth Yates
// 

using System;
using System.Xml;
using System.Configuration;
using Intelligencia.UrlRewriter.Utilities;
using Intelligencia.UrlRewriter.Actions;
using Intelligencia.UrlRewriter.Configuration;

namespace Intelligencia.UrlRewriter.Parsers
{
	/// <summary>
	/// Action parser for the add-header action.
	/// </summary>
	internal class AddHeaderActionParser : RewriteActionParserBase
	{
		/// <summary>
		/// Default constructor.
		/// </summary>
		public AddHeaderActionParser()
		{
		}

		/// <summary>
		/// The name of the action.
		/// </summary>
		public override string Name
		{
			get
			{
				return Constants.ElementAdd;
			}
		}

		/// <summary>
		/// Whether the action allows nested actions.
		/// </summary>
		public override bool AllowsNestedActions
		{
			get
			{
				return false;
			}
		}

		/// <summary>
		/// Whether the action allows attributes.
		/// </summary>
		public override bool AllowsAttributes
		{
			get
			{
				return true;
			}
		}

		/// <summary>
		/// Parses the node.
		/// </summary>
		/// <param name="node">The node to parse.</param>
		/// <param name="config">The rewriter configuration.</param>
		/// <returns>The parsed action, or null if no action parsed.</returns>
		public override IRewriteAction Parse(XmlNode node, object config)
		{
			XmlNode headerNameNode = node.Attributes.GetNamedItem(Constants.AttrHeader);
			if (headerNameNode == null)
			{
				throw new ConfigurationException(MessageProvider.FormatString(Message.AttributeRequired, Constants.AttrHeader), node);
			}

			XmlNode headerValueNode = node.Attributes.GetNamedItem(Constants.AttrValue);
			if (headerValueNode == null)
			{
				throw new ConfigurationException(MessageProvider.FormatString(Message.AttributeRequired, Constants.AttrValue), node);
			}

			return new AddHeaderAction(headerNameNode.Value, headerValueNode.Value);
		}
	}
}
