// UrlRewriter - A .NET URL Rewriter module
// Version 1.5
//
// Copyright 2005 Intelligencia
// Copyright 2005 Seth Yates
// 

using System;
using System.IO;
using System.Net;
using System.Web;
using System.Resources;
using System.Reflection;
using Intelligencia.UrlRewriter.Configuration;
using Intelligencia.UrlRewriter.Utilities;

namespace Intelligencia.UrlRewriter
{
	/// <summary>
	/// Rewrites urls based on patterns and conditions specified in the configuration file.  This class cannot be inherited.
	/// </summary>
	public sealed class RewriterHttpModule : IHttpModule
	{
		/// <summary>
		/// Initialises the module.
		/// </summary>
		/// <param name="context">The application context.</param>
		void IHttpModule.Init(HttpApplication context)
		{
			context.BeginRequest += new EventHandler(BeginRequest);
		}

		/// <summary>
		/// Disposes of the module.
		/// </summary>
		void IHttpModule.Dispose()
		{
		}

		/// <summary>
		/// Configuration of the rewriter.
		/// </summary>
		public static RewriterConfiguration Configuration
		{
			get
			{
				return _rewriter.Configuration;
			}
		}

		private void BeginRequest(object sender, EventArgs e)
		{
			string thisHost = HttpContext.Current.Request.Url.Host;

			// Add our PoweredBy header
			HttpContext.Current.Response.AddHeader(Constants.HeaderXPoweredBy, Configuration.XPoweredBy);

			Rewriter.Rewrite(thisHost);
		}

		internal static RewriterEngine Rewriter
		{
			get
			{
				return _rewriter;
			}
		}

		private static RewriterEngine _rewriter = new RewriterEngine();
	}
}
